@@ -7,19 +7,19 @@ from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
 from ..utils import TimeCounter
 
-abs_path = os.path.dirname(__file__)
+abs_path = os.path.dirname(os.path.dirname(__file__))
 # use different commands for windows and linux respectively
 system = platform.system().lower()
 if system == 'linux':
     rm = 'rm {}'
     mv = 'mv {} {}'
-    align_tool = f"{abs_path}/../software/linux_famsa"
+    align_tool = f"{abs_path}/software/linux_famsa"
     command = align_tool + " {} {} >/dev/null 2>&1"
 
 elif system == 'windows':
     rm = 'del {}'
     mv = 'move {} >nul 2>nul'
-    align_tool = f"{abs_path}\\..\\software\\windows_famsa.exe"
+    align_tool = f"{abs_path}\\software\\windows_famsa.exe"
     command = align_tool + " {} {} >nul 2>nul"
 
 
@@ -67,7 +67,7 @@ def build_msa(fasta_path, out_path, id, fmt='a3m'):
         fasta2a3m(id, out_path)
 
 
-def tsv_to_msa(tsv_path, align=True, fmt='a3m'):
+def tsv_to_msa(tsv_path, output, align=True, fmt='a3m'):
     data = pd.read_csv(tsv_path, sep='\t')
     
     with TimeCounter('Generating files...'):
@@ -75,7 +75,7 @@ def tsv_to_msa(tsv_path, align=True, fmt='a3m'):
             query_id, indices = item
             info = data.iloc[indices].values
             
-            out_name = f"query_{i}.faa"
+            out_name = f"{output}/query_{i}.faa" if output else f"query_{i}.faa"
             with open(out_name, 'w') as f:
                 query_description, query_seq = info[0][1], info[0][4]
                 f.write(f">{query_description}\n{query_seq}\n")
